@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock;
@@ -152,9 +152,8 @@ public class EasyMock {
      * 
      * @return the expectation setter.
      */
-    @SuppressWarnings("unchecked")
     public static <T> IExpectationSetters<T> expect(T value) {
-        return getControlForLastCall();
+        return EasyMock.getControlForLastCall();
     }
 
     /**
@@ -164,17 +163,17 @@ public class EasyMock {
      * 
      * @return the expectation setter.
      */
-    @SuppressWarnings("unchecked")
-    public static IExpectationSetters<Object> expectLastCall() {
+    public static <T> IExpectationSetters<T> expectLastCall() {
         return getControlForLastCall();
     }
 
-    private static IExpectationSetters getControlForLastCall() {
+    @SuppressWarnings("unchecked")
+    private static <T> IExpectationSetters<T> getControlForLastCall() {
         MocksControl lastControl = LastControl.lastControl();
         if (lastControl == null) {
             throw new IllegalStateException("no last call on a mock available");
         }
-        return lastControl;
+        return (IExpectationSetters<T>) lastControl;
     }
 
     /**
@@ -263,7 +262,7 @@ public class EasyMock {
      * 
      * @return <code>null</code>.
      */
-    public static Object anyObject() {
+    public static <T> T anyObject() {
         reportMatcher(Any.ANY);
         return null;
     }
@@ -1258,7 +1257,7 @@ public class EasyMock {
      * 
      * @return <code>null</code>.
      */
-    public static Object isNull() {
+    public static <T> T isNull() {
         reportMatcher(Null.NULL);
         return null;
     }
@@ -1268,7 +1267,7 @@ public class EasyMock {
      * 
      * @return <code>null</code>.
      */
-    public static Object notNull() {
+    public static <T> T notNull() {
         reportMatcher(NotNull.NOT_NULL);
         return null;
     }
@@ -1371,7 +1370,126 @@ public class EasyMock {
         reportMatcher(new Same(value));
         return null;
     }
+    
+    /**
+     * Expects a comparable argument equals to the given value according to their
+     * compareTo method. For details, see the EasMock documentation.
+     * 
+     * @param value
+     *            the given value.
+     * @return <code>null</code>.
+     */
+    public static <T extends Comparable<T>> T cmpEq(Comparable<T> value) {
+        reportMatcher(new CompareEqual<T>(value));
+        return null;
+    }
+    
+    /**
+     * Expects an argument that will be compared using the provided comparator.
+     * The following comparison will take place:
+     * <p>
+     * <code>comparator.compare(actual, expected) operator 0</code>
+     * </p>
+     * For details, see the EasyMock documentation.
+     * 
+     * @param value the given value.
+     * @param comparator Comparator used to compare the actual with expected value.
+     * @param operator The comparison operator.
+     * @return <code>null</code>
+     */
+    public static <T> T cmp(T value, Comparator<? super T> comparator, LogicalOperator operator) {
+        reportMatcher(new Compare<T>(value, comparator, operator));
+        return null;
+    }
 
+
+    /**
+     * Expects a byte that is equal to the given value.
+     * 
+     * @param value
+     *            the given value.
+     * @return <code>0</code>.
+     */
+    
+    
+    /**
+     * Expect any object but captures it for later use.
+     *  
+     * @param <T> Type of the captured object
+     * @param captured Where the parameter is captured
+     * @return <code>null</code>
+     */
+    public static <T> T capture(Capture<T> captured) {
+        reportMatcher(new Captures<T>(captured));
+        return null;
+    }
+    
+    /**
+     * Expect any int but captures it for later use.
+     *  
+     * @param captured Where the parameter is captured
+     * @return <code>0</code>
+     */
+    public static int capture(Capture<Integer> captured) {
+        reportMatcher(new Captures<Integer>(captured));
+        return 0;
+    }
+    
+    /**
+     * Expect any long but captures it for later use.
+     *  
+     * @param captured Where the parameter is captured
+     * @return <code>0</code>
+     */
+    public static long capture(Capture<Long> captured) {
+        reportMatcher(new Captures<Long>(captured));
+        return 0;
+    }
+    
+    /**
+     * Expect any float but captures it for later use.
+     *  
+     * @param captured Where the parameter is captured
+     * @return <code>0</code>
+     */
+    public static float capture(Capture<Float> captured) {
+        reportMatcher(new Captures<Float>(captured));
+        return 0;
+    }
+    
+    /**
+     * Expect any double but captures it for later use.
+     *  
+     * @param captured Where the parameter is captured
+     * @return <code>0</code>
+     */
+    public static double capture(Capture<Double> captured) {
+        reportMatcher(new Captures<Double>(captured));
+        return 0;
+    }
+
+    /**
+     * Expect any byte but captures it for later use.
+     *  
+     * @param captured Where the parameter is captured
+     * @return <code>0</code>
+     */
+    public static byte capture(Capture<Byte> captured) {
+        reportMatcher(new Captures<Byte>(captured));
+        return 0;
+    }
+    
+    /**
+     * Expect any char but captures it for later use.
+     *  
+     * @param captured Where the parameter is captured
+     * @return <code>0</code>
+     */
+    public static char capture(Capture<Character> captured) {
+        reportMatcher(new Captures<Character>(captured));
+        return 0;
+    }
+    
     /**
      * Switches the given mock objects (more exactly: the controls of the mock
      * objects) to replay mode. For details, see the EasyMock documentation.
@@ -1398,6 +1516,48 @@ public class EasyMock {
         }
     }
 
+    /**
+     * Resets the given mock objects (more exactly: the controls of the mock
+     * objects) and turn them to a mock with nice behavior. For details, see 
+     * the EasyMock documentation.
+     * 
+     * @param mocks
+     *            the mock objects
+     */
+    public static void resetToNice(Object... mocks) {
+        for (Object mock : mocks) {
+            getControl(mock).resetToNice();
+        }
+    }
+    
+    /**
+     * Resets the given mock objects (more exactly: the controls of the mock
+     * objects) and turn them to a mock with default behavior. For details, see 
+     * the EasyMock documentation.
+     * 
+     * @param mocks
+     *            the mock objects
+     */
+    public static void resetToDefault(Object... mocks) {
+        for (Object mock : mocks) {
+            getControl(mock).resetToDefault();
+        }
+    }
+    
+    /**
+     * Resets the given mock objects (more exactly: the controls of the mock
+     * objects) and turn them to a mock with strict behavior. For details, see 
+     * the EasyMock documentation.
+     * 
+     * @param mocks
+     *            the mock objects
+     */
+    public static void resetToStrict(Object... mocks) {
+        for (Object mock : mocks) {
+            getControl(mock).resetToStrict();
+        }
+    }
+    
     /**
      * Verifies the given mock objects (more exactly: the controls of the mock
      * objects).
@@ -1460,33 +1620,13 @@ public class EasyMock {
     }
     
     /**
-     * Expects a comparable argument equals to the given value according to their
-     * compareTo method. For details, see the EasyMock documentation.
+     * Makes the mock thread safe. The mock will be usable in a multithreaded
+     * environment.
      * 
-     * @param value
-     *            the given value.
-     * @return <code>null</code>.
+     * @param mock the mock to make thread safe
+     * @param threadSafe If the mock should be thread safe or not
      */
-    public static <T extends Comparable<T>> T cmpEq(Comparable<T> value) {
-        reportMatcher(new CompareEqual<T>(value));
-        return null;
-    }
-    
-    /**
-     * Expects an argument that will be compared using the provided comparator.
-     * The following comparison will take place:
-     * <p>
-     * <code>comparator.compare(actual, expected) operator 0</code>
-     * </p>
-     * For details, see the EasyMock documentation.
-     * 
-     * @param value the given value.
-     * @param comparator Comparator used to compare the actual with expected value.
-     * @param operator The comparison operator.
-     * @return <code>null</code>
-     */
-    public static <T> T cmp(T value, Comparator<T> comparator, LogicalOperator operator) {
-        reportMatcher(new Compare<T>(value, comparator, operator));
-        return null;
+    public static void makeThreadSafe(Object mock, boolean threadSafe) {
+        getControl(mock).makeThreadSafe(threadSafe);
     }
 }
