@@ -1,15 +1,18 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock.internal;
 
+import java.io.Serializable;
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.Method;
 
-public final class MockInvocationHandler implements InvocationHandler {
+public final class MockInvocationHandler implements InvocationHandler, Serializable {
 
-    final MocksControl control;
+    private static final long serialVersionUID = -7799769066534714634L;
+    
+    private final MocksControl control;
 
     public MockInvocationHandler(MocksControl control) {
         this.control = control;
