@@ -1,12 +1,17 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock.internal.matchers;
 
+import java.io.Serializable;
+
 import org.easymock.IArgumentMatcher;
 
-public abstract class CompareTo<T extends Comparable<T>> implements IArgumentMatcher {
+public abstract class CompareTo<T extends Comparable<T>> implements IArgumentMatcher, Serializable {
+
+    private static final long serialVersionUID = -8447010713532143168L;
+    
     private final Comparable<T> expected;
 
     public CompareTo(Comparable<T> value) {
