@@ -1,12 +1,17 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock.internal.matchers;
 
+import java.io.Serializable;
+
 import org.easymock.IArgumentMatcher;
 
-public class EqualsWithDelta implements IArgumentMatcher {
+public class EqualsWithDelta implements IArgumentMatcher, Serializable {
+
+    private static final long serialVersionUID = -3018631689416120154L;
+
     private final Number expected;
 
     private final Number delta;
