@@ -1,12 +1,16 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock.internal.matchers;
 
+import java.io.Serializable;
+
 import org.easymock.IArgumentMatcher;
 
-public class Not implements IArgumentMatcher {
+public class Not implements IArgumentMatcher, Serializable {
+
+    private static final long serialVersionUID = -5160559075998939348L;
 
     private final IArgumentMatcher first;
 
