@@ -1,12 +1,16 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock.internal.matchers;
 
+import java.io.Serializable;
+
 import org.easymock.IArgumentMatcher;
 
-public class NotNull implements IArgumentMatcher {
+public class NotNull implements IArgumentMatcher, Serializable {
+
+    private static final long serialVersionUID = -2689588759855326190L;
 
     public static final NotNull NOT_NULL = new NotNull();
     
