@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2007 OFFIS, Tammo Freese.
+ * Copyright (c) 2001-2008 OFFIS, Tammo Freese.
  * This program is made available under the terms of the MIT License.
  */
 package org.easymock.tests2;
@@ -8,8 +8,11 @@ import static org.easymock.EasyMock.*;
 import static org.junit.Assert.*;
 
 import java.math.BigDecimal;
+import java.util.Collections;
 import java.util.Comparator;
+import java.util.List;
 
+import org.easymock.EasyMock;
 import org.easymock.LogicalOperator;
 import org.easymock.internal.matchers.Equals;
 import org.easymock.tests.IMethods;
@@ -290,10 +293,15 @@ public class UsageConstraintsTest {
 
     @Test
     public void compareWithComparator() {
-        Comparator<A> comparator = new Comparator<A>() {
-            public int compare(A a1, A a2) {
+        // Undertype just to make sure the generic typing works
+        Comparator<Object> comparator = new Comparator<Object>() {
+            private int compare(A a1, A a2) {
                 return a1.getValue() - a2.getValue();
             }
+
+            public int compare(Object o1, Object o2) {
+                return compare((A)o1, (A)o2);
+            }
         };
 
         // Check my comparator works
@@ -374,9 +382,9 @@ public class UsageConstraintsTest {
         expect(mock.oneArg(anyLong())).andReturn("6");
         expect(mock.oneArg(anyShort())).andReturn("7");
         expect(mock.oneArg((String) anyObject())).andReturn("8");
-        expect(mock.oneArg(anyObject())).andReturn("9");
+        expect(mock.oneArg((List<String>) EasyMock.<List<String>>anyObject())).andReturn("9"); // make sure there's no warning on the cast
         replay(mock);
-        assertEquals("9", mock.oneArg(new Object()));
+        assertEquals("9", mock.oneArg(Collections.emptyList()));
         assertEquals("0", mock.oneArg(true));
         assertEquals("1", mock.oneArg((byte) 1));
         assertEquals("2", mock.oneArg((char) 1));
@@ -387,7 +395,7 @@ public class UsageConstraintsTest {
         assertEquals("5", mock.oneArg((int) 1));
         assertEquals("6", mock.oneArg((long) 1));
         verify(mock);
-    }
+    }    
 
     @Test
     public void arrayEquals() {
